@@ -497,11 +497,22 @@ class Database(object):
         for post in data.get('posts', ()):
             pass
 
+        all_start_pos = 0
         for text_dict in data.get('texts', ()):
             lang = text_dict.get('lang')
+            el_start_pos = text_dict.get('position_start', None)
+
             tg = xapian.TermGenerator()
             tg.set_database(self.backend)
             tg.set_document(doc)
+
+            # if the element specifies no start position, set the
+            # starting position where the last element left off
+            if el_start_pos is not None:
+                tg.set_termpos(el_start_pos)
+            else:
+                tg.set_termpos(all_start_pos)
+
             spelling = text_dict.get('spell', True)
             if spelling:
                 try:
@@ -519,13 +530,18 @@ class Database(object):
                 index_text = tg.index_text_without_positions
             text = text_dict.get('text')
             if text:
+                wdf_inc = text_dict.get('wdf_inc', 1)
                 prefix = text_dict.get('prefix')
                 if prefix:
                     self.check_prefix(prefix)
                     prefix = 'X%s:' % prefix.upper()
-                    index_text(text, 1, prefix)
+                    index_text(text, wdf_inc, prefix)
                 else:
-                    index_text(text)
+                    index_text(text, wdf_inc)
+            # if the element specified no start position,
+            # update the all-document position
+            if el_start_pos is None:
+                all_start_pos = tg.get_termpos()
 
         for val_tuple in data.get('values', ()):
             name, value, typ = val_tuple
